MCD weak
Appartement ( #code rue, #num immeuble, #num étage, num appart., nb pièces )

- Le champ code rue, num immeuble, num étage fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Étage pour renforcer l'identifiant.
- Le champ num appart. fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité Appartement.
- Le champ nb pièces était déjà un simple attribut de l'entité Appartement.

Étage ( #code rue, #num immeuble, num étage, nb appartements )

- Le champ code rue, num immeuble fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Immeuble pour renforcer l'identifiant.
- Le champ num étage fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité Étage.
- Le champ nb appartements était déjà un simple attribut de l'entité Étage.

Immeuble ( #code rue, num immeuble, nb étages )

- Le champ code rue fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Rue pour renforcer l'identifiant.
- Le champ num immeuble fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité Immeuble.
- Le champ nb étages était déjà un simple attribut de l'entité Immeuble.

Rue ( code rue, nom rue )

- Le champ code rue constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Rue.
- Le champ nom rue était déjà un simple attribut de l'entité Rue.